class ctpysql:
    def __init__(self, conn):
        self.conn = conn

    def truncate (self, table):
        sql = "truncate {0}".format(table)
        try:
            cursor = self.conn.cursor()
            cursor.execute(sql)
            return self.conn.commit()

        except Error as e:
            return e

        cursor.close()

    def insert (self, table, dic):
        columns = ', '.join("`" + str(i).replace('/', '_') + "`" for i in dic.keys())
        values = ', '.join("'" + str(i).replace('/', '_') + "'" for i in dic.values())
        sql = "INSERT INTO {0} ({1}) VALUES ({2})".format(table, columns, values)
        try:
            cursor = self.conn.cursor()
            cursor.execute(sql)
            return self.conn.commit()

        except Error as e:
            return e

        cursor.close()



from setuptools import setup
setup(
    name='ctpysql',
    version='0.0.1',
    description='This library is for run MYSQL queries as fast as possible 🚄🔥!',
    py_modules=["ctpysql"],
    package_dir={'': 'src'},
    install_requires = [
        "mysql-connector ~= 2.2.9",
        "mysql-connector-python ~= 8.0.23",
    ],
    url="https://github.com/MahyarNV/cautious-pysql",
    author="Mahyar Behzadi",
    author_email="mahyarbhz@gmail.com"
)
